@@ -5,14 +5,14 @@ if test -f ".version"
 then
   VERSION=$(cat .version)
 fi
-if test "x$VERSION" = "x" -a -d "./.git"
+if test -d "./.git"
 then
   VERSION=$(git describe --tags)
-  VERSION=${VERSION:1:${#VERSION}}
+  VERSION=${VERSION#v}
   echo $VERSION > .version
 fi
 if test "x$VERSION" = "x"
 then
   VERSION="unknown"
 fi
-echo -n "$VERSION"
+echo -e "$VERSION\c"
