@@ -174,9 +174,9 @@ timeout_task_cb (void *cls)
 static void
 dht_get_handler (void *cls, struct GNUNET_TIME_Absolute exp,
                  const struct GNUNET_HashCode *key,
-                 const struct GNUNET_PeerIdentity *get_path,
+                 const struct GNUNET_DHT_PathElement *get_path,
                  unsigned int get_path_length,
-                 const struct GNUNET_PeerIdentity *put_path,
+                 const struct GNUNET_DHT_PathElement *put_path,
                  unsigned int put_path_length,
                  enum GNUNET_BLOCK_Type type,
                  size_t size, const void *data)
@@ -261,7 +261,7 @@ monitor_get_cb (void *cls,
                 uint32_t hop_count,
                 uint32_t desired_replication_level,
                 unsigned int path_length,
-                const struct GNUNET_PeerIdentity *path,
+                const struct GNUNET_DHT_PathElement *path,
                 const struct GNUNET_HashCode *key)
 {
   unsigned int i;
@@ -298,7 +298,7 @@ monitor_put_cb (void *cls,
                 uint32_t hop_count,
                 uint32_t desired_replication_level,
                 unsigned int path_length,
-                const struct GNUNET_PeerIdentity *path,
+                const struct GNUNET_DHT_PathElement *path,
                 struct GNUNET_TIME_Absolute exp,
                 const struct GNUNET_HashCode *key,
                 const void *data,
@@ -334,9 +334,9 @@ monitor_put_cb (void *cls,
 static void
 monitor_res_cb (void *cls,
                 enum GNUNET_BLOCK_Type type,
-                const struct GNUNET_PeerIdentity *get_path,
+                const struct GNUNET_DHT_PathElement *get_path,
                 unsigned int get_path_length,
-                const struct GNUNET_PeerIdentity *put_path,
+                const struct GNUNET_DHT_PathElement *put_path,
                 unsigned int put_path_length,
                 struct GNUNET_TIME_Absolute exp,
                 const struct GNUNET_HashCode *key,
