@@ -94,27 +94,22 @@ rd_decrypt_cb (void *cls,
 
 
 static void
-run (void *cls,
-     char *const *args,
-     const char *cfgfile,
-     const struct GNUNET_CONFIGURATION_Handle *cfg)
+test_with_type (struct GNUNET_IDENTITY_PrivateKey *privkey)
 {
   struct GNUNET_GNSRECORD_Block *block;
   struct GNUNET_IDENTITY_PublicKey pubkey;
   struct GNUNET_HashCode query_pub;
   struct GNUNET_HashCode query_priv;
+  struct GNUNET_HashCode query_block;
   struct GNUNET_TIME_Absolute expire = GNUNET_TIME_absolute_get ();
-  struct GNUNET_IDENTITY_PrivateKey privkey;
 
 
-  privkey.type = htonl (GNUNET_GNSRECORD_TYPE_PKEY);
-  GNUNET_CRYPTO_ecdsa_key_create (&privkey.ecdsa_key);
   /* get public key */
-  GNUNET_IDENTITY_key_get_public (&privkey,
+  GNUNET_IDENTITY_key_get_public (privkey,
                                   &pubkey);
 
   /* test query derivation */
-  GNUNET_GNSRECORD_query_from_private_key (&privkey,
+  GNUNET_GNSRECORD_query_from_private_key (privkey,
                                            "testlabel",
                                            &query_priv);
   GNUNET_GNSRECORD_query_from_public_key (&pubkey,
@@ -124,16 +119,23 @@ run (void *cls,
                               &query_pub,
                               sizeof(struct GNUNET_HashCode)));
   /* create record */
-  s_name = "DUMMY.dummy.gnunet";
+  s_name = "testlabel";
   s_rd = create_record (RECORDS);
 
   /* Create block */
-  GNUNET_assert (NULL != (block =
-                            GNUNET_GNSRECORD_block_create (&privkey,
-                                                           expire,
-                                                           s_name,
-                                                           s_rd,
-                                                           RECORDS)));
+  GNUNET_assert (GNUNET_OK == GNUNET_GNSRECORD_block_create (privkey,
+                                                             expire,
+                                                             s_name,
+                                                             s_rd,
+                                                             RECORDS,
+                                                             &block));
+  GNUNET_assert (GNUNET_OK ==
+                 GNUNET_GNSRECORD_query_from_block (block,
+                                                    &query_block));
+  GNUNET_assert (0 == memcmp (&query_pub,
+                              &query_block,
+                              sizeof(struct GNUNET_HashCode)));
+
   GNUNET_assert (GNUNET_OK ==
                  GNUNET_GNSRECORD_block_verify (block));
   GNUNET_assert (GNUNET_OK ==
@@ -146,6 +148,40 @@ run (void *cls,
 }
 
 
+static void
+run (void *cls,
+     char *const *args,
+     const char *cfgfile,
+     const struct GNUNET_CONFIGURATION_Handle *cfg)
+{
+  struct GNUNET_IDENTITY_PrivateKey privkey;
+  struct GNUNET_IDENTITY_PrivateKey privkey_ed;
+  struct GNUNET_TIME_Absolute start;
+  struct GNUNET_TIME_Absolute end;
+
+
+  privkey.type = htonl (GNUNET_GNSRECORD_TYPE_PKEY);
+  GNUNET_CRYPTO_ecdsa_key_create (&privkey.ecdsa_key);
+  start = GNUNET_TIME_absolute_get ();
+  test_with_type (&privkey);
+  end = GNUNET_TIME_absolute_get ();
+  printf ("Time: %llu ms\n", (unsigned long long)
+          GNUNET_TIME_absolute_get_difference (start,
+                                               end).rel_value_us);
+
+  privkey_ed.type = htonl (GNUNET_GNSRECORD_TYPE_EDKEY);
+  GNUNET_CRYPTO_eddsa_key_create (&privkey_ed.eddsa_key);
+  start = GNUNET_TIME_absolute_get ();
+  test_with_type (&privkey_ed);
+  end = GNUNET_TIME_absolute_get ();
+  printf ("Time: %llu ms\n", (unsigned long long)
+          GNUNET_TIME_absolute_get_difference (start,
+                                               end).rel_value_us);
+
+
+}
+
+
 int
 main (int argc, char *argv[])
 {
