@@ -147,6 +147,11 @@ extern "C" {
  */
 #define GNUNET_GNSRECORD_TYPE_TOMBSTONE 65559
 
+/**
+ * Record type to store details about a messenger room
+ */
+#define GNUNET_GNSRECORD_TYPE_MESSENGER_ROOM_DETAILS 65560
+
 
 #if 0 /* keep Emacsens' auto-indent happy */
 {
