@@ -16,7 +16,7 @@
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
      SPDX-License-Identifier: AGPL3.0-or-later
-*/
+ */
 
 /**
  * @author Christian Grothoff
@@ -115,9 +115,10 @@ struct GNUNET_TRANSPORT_AddressToStringContext;
  *        if #GNUNET_NO: address was invalid (or not supported)
  *        if #GNUNET_SYSERR: communication error (IPC error)
  */
-typedef void (*GNUNET_TRANSPORT_AddressToStringCallback) (void *cls,
-                                                          const char *address,
-                                                          int res);
+typedef void
+(*GNUNET_TRANSPORT_AddressToStringCallback) (void *cls,
+                                             const char *address,
+                                             int res);
 
 
 /**
@@ -326,7 +327,8 @@ struct GNUNET_TRANSPORT_PeerMonitoringContext;
  * @param state current state this peer is in
  * @param state_timeout timeout for the current state of the peer
  */
-typedef void (*GNUNET_TRANSPORT_PeerIterateCallback) (
+typedef void
+(*GNUNET_TRANSPORT_PeerIterateCallback) (
   void *cls,
   const struct GNUNET_PeerIdentity *peer,
   const struct GNUNET_HELLO_Address *address,
@@ -394,7 +396,8 @@ struct GNUNET_TRANSPORT_Blacklist;
  * @param pid peer to approve or disapproave
  * @return #GNUNET_OK if the connection is allowed, #GNUNET_SYSERR if not
  */
-typedef int (*GNUNET_TRANSPORT_BlacklistCallback) (
+typedef int
+(*GNUNET_TRANSPORT_BlacklistCallback) (
   void *cls,
   const struct GNUNET_PeerIdentity *pid);
 
@@ -446,7 +449,6 @@ struct GNUNET_TRANSPORT_PluginSession;
  */
 enum GNUNET_TRANSPORT_SessionState
 {
-
   /**
    * The session was created (first call for each session object).
    */
@@ -473,7 +475,6 @@ enum GNUNET_TRANSPORT_SessionState
    * Last call for each session object.
    */
   GNUNET_TRANSPORT_SS_DONE
-
 };
 
 
@@ -482,7 +483,6 @@ enum GNUNET_TRANSPORT_SessionState
  */
 struct GNUNET_TRANSPORT_SessionInfo
 {
-
   /**
    * New state of the session.
    */
@@ -544,7 +544,8 @@ struct GNUNET_TRANSPORT_SessionInfo
  *        NULL with @a session being non-NULL if the monitor
  *        was being cancelled while sessions were active
  */
-typedef void (*GNUNET_TRANSPORT_SessionMonitorCallback) (
+typedef void
+(*GNUNET_TRANSPORT_SessionMonitorCallback) (
   void *cls,
   struct GNUNET_TRANSPORT_PluginSession *session,
   void **session_ctx,
@@ -596,7 +597,8 @@ struct GNUNET_TRANSPORT_CoreHandle;
  * @param mq message queue to use to transmit to @a peer
  * @return closure to use in MQ handlers
  */
-typedef void *(*GNUNET_TRANSPORT_NotifyConnect) (
+typedef void *
+(*GNUNET_TRANSPORT_NotifyConnect) (
   void *cls,
   const struct GNUNET_PeerIdentity *peer,
   struct GNUNET_MQ_Handle *mq);
@@ -613,7 +615,8 @@ typedef void *(*GNUNET_TRANSPORT_NotifyConnect) (
  * @param handlers_cls closure of the handlers, was returned from the
  *                    connect notification callback
  */
-typedef void (*GNUNET_TRANSPORT_NotifyDisconnect) (
+typedef void
+(*GNUNET_TRANSPORT_NotifyDisconnect) (
   void *cls,
   const struct GNUNET_PeerIdentity *peer,
   void *handler_cls);
@@ -635,7 +638,8 @@ typedef void (*GNUNET_TRANSPORT_NotifyDisconnect) (
  * @param handlers_cls closure of the handlers, was returned from the
  *                    connect notification callback
  */
-typedef void (*GNUNET_TRANSPORT_NotifyExcessBandwidth) (
+typedef void
+(*GNUNET_TRANSPORT_NotifyExcessBandwidth) (
   void *cls,
   const struct GNUNET_PeerIdentity *neighbour,
   void *handlers_cls);
