@@ -296,6 +296,30 @@ struct GNUNET_CRYPTO_RsaPublicKeyHeaderP
 GNUNET_NETWORK_STRUCT_END
 
 
+bool
+GNUNET_CRYPTO_rsa_public_key_check (
+  const struct GNUNET_CRYPTO_RsaPublicKey *key)
+{
+  gcry_mpi_t ne[2];
+  int ret;
+
+  ret = key_from_sexp (ne,
+                       key->sexp,
+                       "public-key",
+                       "ne");
+  if (0 != ret)
+    ret = key_from_sexp (ne,
+                         key->sexp,
+                         "rsa",
+                         "ne");
+  if (0 != ret)
+    return false;
+  gcry_mpi_release (ne[0]);
+  gcry_mpi_release (ne[1]);
+  return true;
+}
+
+
 size_t
 GNUNET_CRYPTO_rsa_public_key_encode (
   const struct GNUNET_CRYPTO_RsaPublicKey *key,
@@ -310,9 +334,15 @@ GNUNET_CRYPTO_rsa_public_key_encode (
   struct GNUNET_CRYPTO_RsaPublicKeyHeaderP hdr;
   int ret;
 
-  ret = key_from_sexp (ne, key->sexp, "public-key", "ne");
+  ret = key_from_sexp (ne,
+                       key->sexp,
+                       "public-key",
+                       "ne");
   if (0 != ret)
-    ret = key_from_sexp (ne, key->sexp, "rsa", "ne");
+    ret = key_from_sexp (ne,
+                         key->sexp,
+                         "rsa",
+                         "ne");
   if (0 != ret)
   {
     GNUNET_break (0);
@@ -333,16 +363,25 @@ GNUNET_CRYPTO_rsa_public_key_encode (
        (n_size > UINT16_MAX) )
   {
     GNUNET_break (0);
-    *buffer = NULL;
+    if (NULL != buffer)
+      *buffer = NULL;
     gcry_mpi_release (ne[0]);
     gcry_mpi_release (ne[1]);
     return 0;
   }
   buf_size = n_size + e_size + sizeof (hdr);
+  if (NULL == buffer)
+  {
+    gcry_mpi_release (ne[0]);
+    gcry_mpi_release (ne[1]);
+    return buf_size;
+  }
   buf = GNUNET_malloc (buf_size);
   hdr.modulus_length = htons ((uint16_t) n_size);
   hdr.public_exponent_length = htons ((uint16_t) e_size);
-  memcpy (buf, &hdr, sizeof (hdr));
+  memcpy (buf,
+          &hdr,
+          sizeof (hdr));
   GNUNET_assert (0 ==
                  gcry_mpi_print (GCRYMPI_FMT_USG,
                                  (unsigned char *) &buf[sizeof (hdr)],
@@ -473,7 +512,7 @@ rsa_gcd_validate (gcry_mpi_t r, gcry_mpi_t n)
 /**
  * Create a blinding key
  *
- * @param len length of the key in bits (i.e. 2048)
+ * @param len length of the key in bits (e.g. 2048)
  * @param bks pre-secret to use to derive the blinding key
  * @return the newly created blinding key, NULL if RSA key is malicious
  */
