@@ -193,7 +193,7 @@ struct GNUNET_SCHEDULER_Task
   /**
    * Why is the task ready?  Set after task is added to ready queue.
    * Initially set to zero.  All reasons that have already been
-   * satisfied (i.e.  read or write ready) will be set over time.
+   * satisfied (e.g. read or write ready) will be set over time.
    */
   enum GNUNET_SCHEDULER_Reason reason;
 
@@ -2056,7 +2056,8 @@ GNUNET_SCHEDULER_do_work (struct GNUNET_SCHEDULER_Handle *sh)
        *
        * It might also mean we are busy-waiting because of a programming
        * error in the external event loop.
-       */LOG (GNUNET_ERROR_TYPE_DEBUG,
+       */
+      LOG (GNUNET_ERROR_TYPE_DEBUG,
            "GNUNET_SCHEDULER_do_work did not find any ready "
            "tasks and timeout has not been reached yet.\n");
     }
